@@ -1,13 +1,13 @@
-from sprox.saormprovider import SAORMProvider
+from nose import SkipTest
+from sprox.sa.provider import SAORMProvider
 from sprox.test.base import setup_database, setup_records, SproxTest
 from sprox.test.model import *
-from sprox.widgetselector import SAWidgetSelector
+from sprox.sa.widgetselector import SAWidgetSelector
 import sqlalchemy
 from sqlalchemy.orm import mapper
 from sqlalchemy import MetaData, Table, Column, Integer
 from sqlalchemy.engine import Engine
 from nose.tools import raises, eq_
-from nose import SkipTest
 import datetime
 
 from cgi import FieldStorage
@@ -46,8 +46,8 @@ class TestSAORMProvider(SproxTest):
         session.add(DocumentCategory(document_category_id=2, department_id=1, name=u'Flyer'))
         session.add(DocumentCategory(document_category_id=3, department_id=2, name=u'Balance Sheet'))
         #session.add(DocumentRating(user_id=1, document_id=1, rating=5))
-        session.flush()
-        
+        self.provider.flush()
+
 
     def test_get_fields_with_func(self):
         eq_(self.provider.get_fields(lambda: Town), ['town_id', 'name', 'town_id', 'name'])
@@ -114,8 +114,8 @@ class TestSAORMProvider(SproxTest):
         eq_(field, 'group_name')
 
     def test_get_view_field_name_with_title(self):
-        """ 
-        if it exists, saormprovider should use the 'title' info attribute to 
+        """
+        if it exists, saormprovider should use the 'title' info attribute to
         determine the title column
         """
         field = self.provider.get_view_field_name(User, ['name'])
@@ -200,6 +200,14 @@ class TestSAORMProvider(SproxTest):
         r = self.provider.query(Document, limit=20, offset=0, order_by='category')
         eq_(len(r), 2)
 
+    def test_query_filters(self):
+        cnt, r = self.provider.query(Town, filters={'name':'Golden'})
+        eq_([t.name for t in r], [u'Golden'])
+
+    def test_query_filters_relations(self):
+        cnt, r = self.provider.query(User, filters={'town':1})
+        assert r[0].town.town_id == 1, r
+
     def test_update(self):
         params = {'user_name':u'asdf2', 'password':u'asdf2', 'email_address':u'email@addy.com', 'groups':[1,4], 'town':2}
         new_user = self.provider.create(User, params)
@@ -240,11 +248,14 @@ class TestSAORMProvider(SproxTest):
         user = self.provider.delete(User, params={'user_id':1})
         users = self.session.query(User).all()
         assert len(users) == 0
-    
+
+    def test_modify_params_for_datetimes(self):
+        params = self.provider._modify_params_for_dates(Example, {'datetime_': '1978-8-29 12:34:56'})
+        eq_(params,  {'datetime_': datetime.datetime(1978, 8, 29, 12, 34, 56)})
 
     def test_modify_params_for_dates(self):
         params = self.provider._modify_params_for_dates(Example, {'date_': '1978-8-29'})
-        eq_(params,  {'date_': datetime.datetime(1978, 8, 29, 0, 0)})
+        eq_(params,  {'date_': datetime.date(1978, 8, 29)})
 
     def test_modify_params_for_intervals(self):
         params = self.provider._modify_params_for_dates(Example, {'interval': '1 days, 3:20:01'})
@@ -255,6 +266,10 @@ class TestSAORMProvider(SproxTest):
         params = {'groups':group}
         params = self.provider._modify_params_for_relationships(User, params)
         assert params['groups'] == [group], params
+        
+    def test_get_field_widget_args(self):
+        a = self.provider.get_field_widget_args(User, 'groups', User.groups)
+        eq_(a, {'nullable': False, 'provider': self.provider})
 
     def test_create_with_unicode_cast_to_int(self):
         self.provider.create(User, dict(user_id=u'34', user_name=u'something'))
